@@ -2,12 +2,18 @@
 
 import re
 import gtk
+import gobject
 
 
 
-class Record:
-    def __init__(self, id, name, user, password, category, info):
-        self.id=id
+class Record(gobject.GObject):
+    #
+    # A record represents a single database entry
+    #
+    def __init__(self):
+        gobject.GObject.__init__(self)
+
+    def setValues(self, name, user, password, category, info):
         self.name=name
         self.user=user
         self.password=password
@@ -27,58 +33,47 @@ class Record:
         return result
 
     def toTuple(self):
-        return (self.id,self.name)
-        #return [self.id,self.name,self.user,self.password,self.category, self.info]
+        return (self,self.name)
     
 
 class DataStore(gtk.ListStore):
 
+    #
+    # This class contains both the entire database (in the records
+    # array) and the currently visible main window entries (in the
+    # inherited ListStore).
+    #
+
     def __init__(self):
-        #gtk.ListStore.__init__(self,int,str,str,str,str,str)
-        gtk.ListStore.__init__(self,int,str)
+        # each model entry consists of the record and the record name
+        gtk.ListStore.__init__(self,Record,str)
         self.set_sort_column_id(1,gtk.SORT_ASCENDING)
         self.clearRecords()
 
 
     def clearRecords(self):
-        self.records=[]
+        # nuke both the record list and the display model
         self.clear()
-        self.lastId=0
+        self.records=[]
 
     def deleteRecord(self, iter):
-        recordId=self[iter][0]
-        #print "Deleting entry",self[iter][1],"index",recordId
+        record=self[iter][0]
+        # remove the entry from the list model ...
         self.remove(iter)
-        del self.records[recordId]
-        # Adjust list indices for all ListStore entries that are
-        # behind the deleted one
-        iter=self.get_iter_first()
-        while iter!=None:
-            id=self[iter][0]
-            if id>recordId:
-                #print "Adjusting index for entry",self[iter][1],"from",id
-                self.set(iter,0, id-1)
-                #print "  new value",self[iter][0]
-            iter=self.iter_next(iter)
-        # Also adjust the 'id' field of the record itself
-        # <SMELL> that field should be made unnecessary!
-        for r in self.records:
-            if r.id>recordId:
-                r.id-=1
+        # ... and remove it from the data store
+        # Note: this can throw an exception if record is not part of
+        # the records list, but I guess that can't happen
+        self.records.remove(record)
 
 
     def addRecord(self, name, user, password, category, info):
-        record=Record(self.lastId, name, user, password, category, info)
+        record=Record()
+        record.setValues(name, user, password, category, info)
         self.records.append(record)
-        self.lastId+=1
         return record
         
-
-    #def add(self, name, user, password, category, info):
-    #    tuple=(name,user,password,category,info)
-    #    self.db.append(tuple)
-
     def getCategories(self):
+        # return a list of all the sorted, unique category strings
         result=[]
         result.append('')
         for record in self.records:
@@ -93,12 +88,14 @@ class DataStore(gtk.ListStore):
             print "%s %s" % (tuple[0], tuple[1])
 
     def toString(self):
+        # Create a string of the databse for saving to disk
         result=''
         for record in self.records:
             result+=record.toString()
         return result
 
     def fromString(self, s):
+        # initialize the database, e.g. from the decrypted file
         name=None
         user=''
         password=''
@@ -142,12 +139,17 @@ class DataStore(gtk.ListStore):
         if name!=None:
             self.addRecord(name, user, password, category, info)
 
+
+
     def filter(self, search, category):
+        # Initialize the list model base on the list of records, a
+        # search string, and the category to filter for
         self.clear()
         result=0
         for record in self.records:
             if (category=='' or record.category==category) and (search=='' or record.name.find(search)>=0):
-                self.append(record.toTuple())
+                tuple=record.toTuple()
+                self.append(tuple)
                 result+=1
             else:
                 record.iter=None
@@ -156,9 +158,8 @@ class DataStore(gtk.ListStore):
             
 
 
-
-
 if __name__=="__main__":
+    # dummy main code, not used
     store=DataStore()
     store.append(['My Bank', 'johndoe', 'secret', 'money', "foo\nbar"])
     store.append(['Google', 'xyz123', 'secret', 'internet', "Since 12/23/2009"])
