@@ -36,7 +36,7 @@ except:
     isHildon=False
 
 
-version="0.6"
+version="0.7"
 
 # The file header
 HEADER="#TrustMe 1"
@@ -307,7 +307,6 @@ class MainPanel(Panel):
         #print "in prepare"
         self.updateSearch()
         self.searchMask.set_text('')
-        self.searchCategory.set_active(-1)
         # force update of the model
         self.searchCb()
         self.main.startAlarm()
@@ -320,19 +319,30 @@ class MainPanel(Panel):
         self.main.store.filter(mask, category)
 
     def updateSearch(self):
+        # return -1 if the category was invalidated
         currentCategory=self.searchCategory.get_active_text()
         self.searchCategory.get_model().clear()
         categories=self.main.store.getCategories()
+        categoryIndex=-1
+        i=0
         for cat in categories:
             self.searchCategory.append_text(cat)
+            if cat==currentCategory:
+                categoryIndex=i
+            i+=1
+        self.searchCategory.set_active(categoryIndex)
+        return categoryIndex
+        
 
     def addCb(self, dummy):
         store=self.main.store
+        # add a new record
         record=store.addRecord('', '', '', '', '')
         count=store.filter('', '')
+        # determine the iterator of the new entry
         iter=store.get_iter_first()
         while iter!=None:
-            if store[iter][0]==record.id:
+            if store[iter][0]==record:
                 break
             iter=store.iter_next(iter)
         if iter:
@@ -347,9 +357,7 @@ class MainPanel(Panel):
         selection=self.treeview.get_selection()
         (dummy, iter)=selection.get_selected()
         if iter!=None:
-            recordId=store[iter][0]
-            #print "Editing",store[iter][1],"index",recordId
-            record=store.records[recordId]
+            record=store[iter][0]
             self.main.editPanel.activate(record)
 
     def deleteCb(self, widget):
@@ -368,6 +376,10 @@ class MainPanel(Panel):
             if result==gtk.RESPONSE_YES:
                 self.main.store.deleteRecord(iter)
                 self.main.save()
+                # category may have been invalidated
+                if self.updateSearch()<0:
+                    # yes, re-do the search
+                    self.searchCb()
 
 
 class EditPanel(Panel):
@@ -425,11 +437,6 @@ class EditPanel(Panel):
 
         withScroll=True
         if withScroll:
-            #frame=gtk.Frame(" Info ")
-            #self.grid.attach(frame, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
-            #frame.set_shadow_type(gtk.SHADOW_IN)
-            #frame.set_border_width(3)
-        
             scroll=gtk.ScrolledWindow()
             self.grid.attach(scroll, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
             #frame.add(scroll)
@@ -458,7 +465,6 @@ class EditPanel(Panel):
         self.addButton('Cancel', self.cancelCb)
         self.lockButton=self.addButton('Lock', self.main.lockCb, packAtEnd=True)
 
-
         self.grid=gtk.Table(rows=5, columns=2)
         self.vbox.pack_start(self.grid, fill=True)
         self.nameEntry=self.makeEntry(0, 'Name')
@@ -477,7 +483,7 @@ class EditPanel(Panel):
         for cat in self.main.store.getCategories():
             self.model.append((cat,))
 
-        self.record_id=record.id
+        self.record=record
         # set the data fields
         self.nameEntry.set_text(record.name)
         self.userEntry.set_text(record.user)
@@ -498,28 +504,20 @@ class EditPanel(Panel):
         return result
 
     def commitCb(self, dummy):
-        # create a Record object from the entry fields
-        newRecord=self.getRecord()
-        # restore original integer identifier
-        newRecord.id=self.record_id
-        # replace the old record data with the new one
-        store=self.main.store
-        store.records[self.record_id]=newRecord
-        iter=store.get_iter_first()
-        while iter!=None:
-            if store[iter][0]==self.record_id:
-                break
-            iter=store.iter_next(iter)
-        if iter:
-            store[iter][1]=newRecord.name
-        else:
-            print "Warning: could not find matching iter for record ID"
+        #  Update the database record
+        buffer=self.infoText.get_buffer()
+        self.record.setValues(
+            self.nameEntry.get_text(),
+            self.userEntry.get_text(),
+            self.passwordEntry.get_text(),
+            self.categoryEntry.get_text(),
+            buffer.get_text(buffer.get_start_iter(), buffer.get_end_iter()))
         # write things to disk
         self.main.save()
-        # switch to main panel
+        # switch to main panel; this also takes care of updating the main
+        # window
         self.main.mainPanel.activate()
 
-
     def cancelCb(self, dummy):
         self.main.mainPanel.activate()
         
